@@ -42,9 +42,10 @@ def BNF():
         expr = Forward()
         atom = ( pi | e | fnumber | ident + lpar + expr + rpar ).setParseAction( pushFirst ) | ( lpar + expr.suppress() + rpar )
         
-        # by defining exponentiation as "atom [ ^ expr ]..." instead of "atom [ ^ atom ]...", we get right-to-left exponents, instead of left-to-righ
+        # by defining exponentiation as "atom [ ^ factor ]..." instead of "atom [ ^ atom ]...", we get right-to-left exponents, instead of left-to-righ
         # that is, 2^3^2 = 2^(3^2), not (2^3)^2.
-        factor = atom + ZeroOrMore( ( expop + expr ).setParseAction( pushFirst ) )
+        factor = Forward()
+        factor << atom + ZeroOrMore( ( expop + factor ).setParseAction( pushFirst ) )
         
         term = factor + ZeroOrMore( ( multop + factor ).setParseAction( pushFirst ) )
         expr << term + ZeroOrMore( ( addop + term ).setParseAction( pushFirst ) )
@@ -106,6 +107,7 @@ if __name__ == "__main__":
     test( "trunc(E)" )
     test( "E^PI" )
     test( "2^3^2" )
+    test( "2^3+2" )
     test( "2^9" )
     test( "sgn(-2)" )
     test( "sgn(0)" )
